@@ -27,6 +27,7 @@ OC.L10N.register(
     "Could not complete login" : "Could not complete login",
     "State token missing" : "State token missing",
     "Your login token is invalid or has expired" : "Your login token is invalid or has expired",
+    "Please use original client" : "Please use original client",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "This community release of Nextcloud is unsupported and push notifications are limited.",
     "Login" : "Login",
     "Unsupported email length (>255)" : "Unsupported email length (>255)",
@@ -103,12 +104,12 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} notification","{count} notifications"],
     "No" : "No",
     "Yes" : "Yes",
-    "Federated user" : "Federated user",
-    "user@your-nextcloud.org" : "user@your-nextcloud.org",
-    "Create share" : "Create share",
     "The remote URL must include the user." : "The remote URL must include the user.",
     "Invalid remote URL." : "Invalid remote URL.",
     "Failed to add the public link to your Nextcloud" : "Failed to add the public link to your Nextcloud",
+    "Federated user" : "Federated user",
+    "user@your-nextcloud.org" : "user@your-nextcloud.org",
+    "Create share" : "Create share",
     "Direct link copied to clipboard" : "Direct link copied to clipboard",
     "Please copy the link manually:" : "Please copy the link manually:",
     "Custom date range" : "Custom date range",
@@ -118,56 +119,61 @@ OC.L10N.register(
     "Search in current app" : "Search in current app",
     "Clear search" : "Clear search",
     "Search everywhere" : "Search everywhere",
-    "Unified search" : "Unified search",
-    "Search apps, files, tags, messages" : "Search apps, files, tags, messages",
-    "Places" : "Places",
-    "Date" : "Date",
+    "Searching …" : "Searching …",
+    "Start typing to search" : "Start typing to search",
+    "No matching results" : "No matching results",
     "Today" : "Today",
     "Last 7 days" : "Last 7 days",
     "Last 30 days" : "Last 30 days",
     "This year" : "This year",
     "Last year" : "Last year",
+    "Unified search" : "Unified search",
+    "Search apps, files, tags, messages" : "Search apps, files, tags, messages",
+    "Places" : "Places",
+    "Date" : "Date",
     "Search people" : "Search people",
     "People" : "People",
     "Filter in current view" : "Filter in current view",
     "Results" : "Results",
     "Load more results" : "Load more results",
     "Search in" : "Search in",
-    "Searching …" : "Searching …",
-    "Start typing to search" : "Start typing to search",
-    "No matching results" : "No matching results",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}",
     "Log in" : "Log in",
     "Logging in …" : "Logging in …",
-    "Server side authentication failed!" : "Server side authentication failed!",
-    "Please contact your administrator." : "Please contact your administrator.",
-    "Temporary error" : "Temporary error",
-    "Please try again." : "Please try again.",
-    "An internal error occurred." : "An internal error occurred.",
-    "Please try again or contact your administrator." : "Please try again or contact your administrator.",
-    "Password" : "Password",
     "Log in to {productName}" : "Log in to {productName}",
     "Wrong login or password." : "Wrong login or password.",
     "This account is disabled" : "This account is disabled",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds.",
     "Account name or email" : "Account name or email",
     "Account name" : "Account name",
+    "Server side authentication failed!" : "Server side authentication failed!",
+    "Please contact your administrator." : "Please contact your administrator.",
+    "Session error" : "Session error",
+    "It appears your session token has expired, please refresh the page and try again." : "It appears your session token has expired, please refresh the page and try again.",
+    "An internal error occurred." : "An internal error occurred.",
+    "Please try again or contact your administrator." : "Please try again or contact your administrator.",
+    "Password" : "Password",
     "Log in with a device" : "Log in with a device",
     "Login or email" : "Login or email",
     "Your account is not setup for passwordless login." : "Your account is not setup for passwordless login.",
-    "Browser not supported" : "Browser not supported",
-    "Passwordless authentication is not supported in your browser." : "Passwordless authentication is not supported in your browser.",
     "Your connection is not secure" : "Your connection is not secure",
     "Passwordless authentication is only available over a secure connection." : "Passwordless authentication is only available over a secure connection.",
+    "Browser not supported" : "Browser not supported",
+    "Passwordless authentication is not supported in your browser." : "Passwordless authentication is not supported in your browser.",
     "Reset password" : "Reset password",
+    "Back to login" : "Back to login",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help.",
     "Couldn't send reset email. Please contact your administrator." : "Couldn't send reset email. Please contact your administrator.",
     "Password cannot be changed. Please contact your administrator." : "Password cannot be changed. Please contact your administrator.",
-    "Back to login" : "Back to login",
     "New password" : "New password",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?",
     "I know what I'm doing" : "I know what I'm doing",
     "Resetting password" : "Resetting password",
+    "Schedule work & meetings, synced with all your devices." : "Schedule work & meetings, synced with all your devices.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Keep your colleagues and friends in one place without leaking their private info.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simple email app nicely integrated with Files, Contacts and Calendar.",
+    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps.",
+    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collaborative documents, spreadsheets and presentations, built on Collabora Online.",
+    "Distraction free note taking app." : "Distraction free note taking app.",
     "Recommended apps" : "Recommended apps",
     "Loading apps …" : "Loading apps …",
     "Could not fetch list of apps from the App Store." : "Could not fetch list of apps from the App Store.",
@@ -177,14 +183,10 @@ OC.L10N.register(
     "Skip" : "Skip",
     "Installing apps …" : "Installing apps …",
     "Install recommended apps" : "Install recommended apps",
-    "Schedule work & meetings, synced with all your devices." : "Schedule work & meetings, synced with all your devices.",
-    "Keep your colleagues and friends in one place without leaking their private info." : "Keep your colleagues and friends in one place without leaking their private info.",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simple email app nicely integrated with Files, Contacts and Calendar.",
-    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps.",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collaborative documents, spreadsheets and presentations, built on Collabora Online.",
-    "Distraction free note taking app." : "Distraction free note taking app.",
-    "Settings menu" : "Settings menu",
     "Avatar of {displayName}" : "Avatar of {displayName}",
+    "Settings menu" : "Settings menu",
+    "Loading your contacts …" : "Loading your contacts …",
+    "Looking for {term} …" : "Looking for {term} …",
     "Search contacts" : "Search contacts",
     "Reset search" : "Reset search",
     "Search contacts …" : "Search contacts …",
@@ -192,26 +194,61 @@ OC.L10N.register(
     "No contacts found" : "No contacts found",
     "Show all contacts" : "Show all contacts",
     "Install the Contacts app" : "Install the Contacts app",
-    "Loading your contacts …" : "Loading your contacts …",
-    "Looking for {term} …" : "Looking for {term} …",
-    "Search starts once you start typing and results may be reached with the arrow keys" : "Search starts once you start typing and results may be reached with the arrow keys",
-    "Search for {name} only" : "Search for {name} only",
-    "Loading more results …" : "Loading more results …",
     "Search" : "Search",
     "No results for {query}" : "No results for {query}",
     "Press Enter to start searching" : "Press Enter to start searching",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Please enter {minSearchLength} character or more to search","Please enter {minSearchLength} characters or more to search"],
     "An error occurred while searching for {type}" : "An error occurred while searching for {type}",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "Search starts once you start typing and results may be reached with the arrow keys",
+    "Search for {name} only" : "Search for {name} only",
+    "Loading more results …" : "Loading more results …",
     "Forgot password?" : "Forgot password?",
     "Back to login form" : "Back to login form",
     "Back" : "Back",
     "Login form is disabled." : "Login form is disabled.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "The Nextcloud login form is disabled. Use another login option if available or contact your administration.",
     "More actions" : "More actions",
+    "Password is too weak" : "Password is too weak",
+    "Password is weak" : "Password is weak",
+    "Password is average" : "Password is average",
+    "Password is strong" : "Password is strong",
+    "Password is very strong" : "Password is very strong",
+    "Password is extremely strong" : "Password is extremely strong",
+    "Unknown password strength" : "Unknown password strength",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}",
+    "Autoconfig file detected" : "Autoconfig file detected",
+    "The setup form below is pre-filled with the values from the config file." : "The setup form below is pre-filled with the values from the config file.",
+    "Security warning" : "Security warning",
+    "Create administration account" : "Create administration account",
+    "Administration account name" : "Administration account name",
+    "Administration account password" : "Administration account password",
+    "Storage & database" : "Storage & database",
+    "Data folder" : "Data folder",
+    "Database configuration" : "Database configuration",
+    "Only {firstAndOnlyDatabase} is available." : "Only {firstAndOnlyDatabase} is available.",
+    "Install and activate additional PHP modules to choose other database types." : "Install and activate additional PHP modules to choose other database types.",
+    "For more details check out the documentation." : "For more details check out the documentation.",
+    "Performance warning" : "Performance warning",
+    "You chose SQLite as database." : "You chose SQLite as database.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite should only be used for minimal and development instances. For production we recommend a different database backend.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "If you use clients for file syncing, the use of SQLite is highly discouraged.",
+    "Database user" : "Database user",
+    "Database password" : "Database password",
+    "Database name" : "Database name",
+    "Database tablespace" : "Database tablespace",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
+    "Database host" : "Database host",
+    "localhost" : "localhost",
+    "Installing …" : "Installing …",
+    "Install" : "Install",
+    "Need help?" : "Need help?",
+    "See the documentation" : "See the documentation",
+    "{name} version {version} and above" : "{name} version {version} and above",
     "This browser is not supported" : "This browser is not supported",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Your browser is not supported. Please upgrade to a newer version or a supported one.",
     "Continue with this unsupported browser" : "Continue with this unsupported browser",
     "Supported versions" : "Supported versions",
-    "{name} version {version} and above" : "{name} version {version} and above",
     "Search {types} …" : "Search {types} …",
     "Choose {file}" : "Choose {file}",
     "Choose" : "Choose",
@@ -247,11 +284,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Type to search for existing projects",
     "New in" : "New in",
     "View changelog" : "View changelog",
-    "Very weak password" : "Very weak password",
-    "Weak password" : "Weak password",
-    "So-so password" : "So-so password",
-    "Good password" : "Good password",
-    "Strong password" : "Strong password",
     "No action available" : "No action available",
     "Error fetching contact actions" : "Error fetching contact actions",
     "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialogue",
@@ -289,34 +321,6 @@ OC.L10N.register(
     "File: %s" : "File: %s",
     "Line: %s" : "Line: %s",
     "Trace" : "Trace",
-    "Security warning" : "Security warning",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Create an admin account</strong>",
-    "New admin account name" : "New admin account name",
-    "New admin password" : "New admin password",
-    "Show password" : "Show password",
-    "Toggle password visibility" : "Toggle password visibility",
-    "Storage & database" : "Storage & database",
-    "Data folder" : "Data folder",
-    "Configure the database" : "Configure the database",
-    "Only %s is available." : "Only %s is available.",
-    "Install and activate additional PHP modules to choose other database types." : "Install and activate additional PHP modules to choose other database types.",
-    "For more details check out the documentation." : "For more details check out the documentation.",
-    "Database account" : "Database account",
-    "Database password" : "Database password",
-    "Database name" : "Database name",
-    "Database tablespace" : "Database tablespace",
-    "Database host" : "Database host",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
-    "Performance warning" : "Performance warning",
-    "You chose SQLite as database." : "You chose SQLite as database.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite should only be used for minimal and development instances. For production we recommend a different database backend.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "If you use clients for file syncing, the use of SQLite is highly discouraged.",
-    "Install" : "Install",
-    "Installing …" : "Installing …",
-    "Need help?" : "Need help?",
-    "See the documentation" : "See the documentation",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Could not remove CAN_INSTALL from the config folder. Please remove this file manually.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page.",
@@ -375,46 +379,32 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
     "This page will refresh itself when the instance is available again." : "This page will refresh itself when the instance is available again.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contact your system administrator if this message persists or appeared unexpectedly.",
-    "The user limit of this instance is reached." : "The user limit of this instance is reached.",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies.",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Your web server is not yet properly set up to allow file synchronisation, because the WebDAV interface seems to be broken.",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}.",
-    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}.",
-    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly.",
-    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
-    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}.",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}.",
-    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!",
     "Currently open" : "Currently open",
-    "Wrong username or password." : "Wrong username or password.",
-    "User disabled" : "User disabled",
     "Login with username or email" : "Login with username or email",
     "Login with username" : "Login with username",
-    "Username or email" : "Username or email",
-    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps.",
-    "Edit Profile" : "Edit Profile",
-    "The headline and about sections will show up here" : "The headline and about sections will show up here",
     "You have not added any info yet" : "You have not added any info yet",
     "{user} has not added any info yet" : "{user} has not added any info yet",
     "Error opening the user status modal, try hard refreshing the page" : "Error opening the user status modal, try hard refreshing the page",
-    "Apps and Settings" : "Apps and Settings",
+    "Edit Profile" : "Edit Profile",
+    "The headline and about sections will show up here" : "The headline and about sections will show up here",
     "Error loading message template: {error}" : "Error loading message template: {error}",
-    "Users" : "Users",
+    "Very weak password" : "Very weak password",
+    "Weak password" : "Weak password",
+    "So-so password" : "So-so password",
+    "Good password" : "Good password",
+    "Strong password" : "Strong password",
     "Profile not found" : "Profile not found",
     "The profile does not exist." : "The profile does not exist.",
-    "Create an <strong>admin account</strong>" : "Create an <strong>admin account</strong>",
-    "Username" : "Username",
-    "Database user" : "Database user",
-    "This action requires you to confirm your password" : "This action requires you to confirm your password",
-    "Confirm your password" : "Confirm your password",
-    "Confirm" : "Confirm",
-    "App token" : "App token",
-    "Alternative log in using app token" : "Alternative log in using app token",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Please use the command line updater because you have a big instance with more than 50 users."
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Create an admin account</strong>",
+    "New admin account name" : "New admin account name",
+    "New admin password" : "New admin password",
+    "Show password" : "Show password",
+    "Toggle password visibility" : "Toggle password visibility",
+    "Configure the database" : "Configure the database",
+    "Only %s is available." : "Only %s is available.",
+    "Database account" : "Database account"
 },
 "nplurals=2; plural=(n != 1);");
