@@ -15,7 +15,7 @@ OC.L10N.register(
     "A PHP extension stopped the file upload" : "Een PHP-extensie blokkeerde de upload.",
     "Invalid file provided" : "Ongeldig bestand opgegeven",
     "No image or file provided" : "Geen afbeelding of bestand opgegeven",
-    "Unknown filetype" : "Bestandsformaat onbekend",
+    "Unknown filetype" : "Onbekend bestandsformaat",
     "An error occurred. Please contact your admin." : "Er trad een fout op. Neem contact op met je beheerder.",
     "Invalid image" : "Afbeelding ongeldig",
     "No temporary profile picture available, try again" : "Geen tijdelijke profielafbeelding beschikbaar. Probeer het opnieuw",
@@ -33,15 +33,17 @@ OC.L10N.register(
     "Password reset is disabled" : "Wachtwoordreset is uitgeschakeld",
     "Could not reset password because the token is expired" : "Kon wachtwoord niet resetten omdat de token verlopen is",
     "Could not reset password because the token is invalid" : "Kon wachtwoord niet resetten omdat de token ongeldig is",
-    "Password is too long. Maximum allowed length is 469 characters." : "Wachtwoord is te lang. Maximum toegestande lengte is 469 karakters.",
+    "Password is too long. Maximum allowed length is 469 characters." : "Wachtwoord is te lang. Maximum toegestane lengte is 469 karakters.",
     "%s password reset" : "%s reset wachtwoord",
     "Password reset" : "Wachtwoordreset",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klik op de volgende knop om je wachtwoord te resetten. Als je geen wachtwoordreset hebt aangevraagd, negeer dan dit e-mailbericht.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klik op de volgende link om je wachtwoord te resetten. Als je geen wachtwoordherstel hebt aangevraagd, negeer dan dit e-mailbericht.",
     "Reset your password" : "Reset je wachtwoord",
+    "The given provider is not available" : "De opgegeven provider is niet beschikbaar",
     "Task not found" : "Taak niet gevonden",
     "Internal error" : "Interne fout",
     "Not found" : "Niet gevonden",
+    "Bad request" : "Ongeldige aanvraag",
     "Requested task type does not exist" : "Het aangevraagde taaktype bestaat niet",
     "Necessary language model provider is not available" : "De nodige taalmodel provider is niet beschikbaar",
     "No text to image provider is available" : "Geen text naar afbeelding aanbieder beschikbaar",
@@ -101,8 +103,14 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} melding","{count} meldingen"],
     "No" : "Nee",
     "Yes" : "Ja",
-    "Create share" : "Creëren share",
+    "The remote URL must include the user." : "De externe URL moet de gebruiker bevatten.",
+    "Invalid remote URL." : "Ongeldige externe URL.",
     "Failed to add the public link to your Nextcloud" : "Kon de openbare link niet aan je Nextcloud toevoegen",
+    "Federated user" : "Gefedereerde gebruiker",
+    "user@your-nextcloud.org" : "gebruiker@your-nextcloud.org",
+    "Create share" : "Creëren share",
+    "Direct link copied to clipboard" : "Directe link gekopieerd naar klembord",
+    "Please copy the link manually:" : "Kopieer de link handmatig:",
     "Custom date range" : "Aangepast datumbereik",
     "Pick start date" : "Kies startdatum",
     "Pick end date" : "Kies einddatum",
@@ -110,56 +118,59 @@ OC.L10N.register(
     "Search in current app" : "Zoek in huidige app",
     "Clear search" : "Wis zoekvak",
     "Search everywhere" : "Zoek in alles",
-    "Unified search" : "Geünificeerd zoeken",
-    "Search apps, files, tags, messages" : "Zoek apps, bestanden, berichten",
-    "Places" : "Locaties",
-    "Date" : "Datum",
+    "Searching …" : "Zoeken ...",
+    "Start typing to search" : "Begin met typen om te zoeken",
+    "No matching results" : "Geen resultaten",
     "Today" : "Vandaag",
     "Last 7 days" : "Laatste 7 dagen",
     "Last 30 days" : "Laatste 30 dagen",
     "This year" : "Dit jaar",
     "Last year" : "Vorig jaar",
+    "Unified search" : "Geünificeerd zoeken",
+    "Search apps, files, tags, messages" : "Zoek apps, bestanden, berichten",
+    "Places" : "Locaties",
+    "Date" : "Datum",
     "Search people" : "Zoek mensen",
     "People" : "Mensen",
     "Filter in current view" : "Beperk tot huidige weergave",
     "Results" : "Resultaten",
     "Load more results" : "Laad meer resultaten",
     "Search in" : "Zoek in",
-    "Searching …" : "Zoeken ...",
-    "Start typing to search" : "Begin met typen om te zoeken",
-    "No matching results" : "Geen resultaten",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Tussen ${this.dateFilter.startFrom.toLocaleDateString()} en ${this.dateFilter.endAt.toLocaleDateString()}",
     "Log in" : "Inloggen",
     "Logging in …" : "Inloggen...",
-    "Server side authentication failed!" : "Authenticatie bij de server mislukt!",
-    "Please contact your administrator." : "Neem contact op met je systeembeheerder.",
-    "Temporary error" : "Tijdelijke fout",
-    "Please try again." : "Gelieve opnieuw te proberen",
-    "An internal error occurred." : "Er heeft zich een interne fout voorgedaan.",
-    "Please try again or contact your administrator." : "Probeer het opnieuw of neem contact op met je beheerder.",
-    "Password" : "Wachtwoord",
     "Log in to {productName}" : "Inloggen bij {productName}",
     "Wrong login or password." : "Verkeerde login of wachtwoord.",
     "This account is disabled" : "Dit account is uitgeschakeld",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We hebben meerdere foutieve inlogverzoeken vanaf jouw IP-adres gedetecteerd. Hierdoor wordt je volgende inlogverzoek 30 seconden uitgesteld.",
     "Account name or email" : "Gebruikersnaam of email",
     "Account name" : "Accountnaam",
+    "Server side authentication failed!" : "Authenticatie bij de server mislukt!",
+    "Please contact your administrator." : "Neem contact op met je systeembeheerder.",
+    "An internal error occurred." : "Er heeft zich een interne fout voorgedaan.",
+    "Please try again or contact your administrator." : "Probeer het opnieuw of neem contact op met je beheerder.",
+    "Password" : "Wachtwoord",
     "Log in with a device" : "Inloggen met een apparaat",
     "Login or email" : "Login of email",
     "Your account is not setup for passwordless login." : "Je account is niet ingesteld voor inloggen zonder wachtwoord.",
-    "Browser not supported" : "Browser niet ondersteund",
-    "Passwordless authentication is not supported in your browser." : "Inloggen zonder wachtwoord is niet ondersteund door je browser.",
     "Your connection is not secure" : "Je verbinding is niet veilig",
     "Passwordless authentication is only available over a secure connection." : "Inloggen zonder wachtwoord is alleen mogelijk over een beveiligde verbinding.",
+    "Browser not supported" : "Browser niet ondersteund",
+    "Passwordless authentication is not supported in your browser." : "Inloggen zonder wachtwoord is niet ondersteund door je browser.",
     "Reset password" : "Reset wachtwoord",
+    "Back to login" : "Terug naar inloggen",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Als dit account bestaat, werd er een wachtwoordherstel email naar het overeenkomstige email adres gestuurd. Krijg je geen mail? Controleer dan het e-mailadres en/of de login, check je spam folder of vraag hulp aan je  beheerder.",
     "Couldn't send reset email. Please contact your administrator." : "Kon herstel email niet versturen. Neem contact op met je beheerder.",
     "Password cannot be changed. Please contact your administrator." : "Het wachtwoord kan niet worden gewijzigd. Neem contact op met je beheerder.",
-    "Back to login" : "Terug naar inloggen",
     "New password" : "Nieuw wachtwoord",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Je bestanden zijn versleuteld. Het is niet mogelijk om je gegevens terug te krijgen als je wachtwoord wordt gereset. Als je niet zeker weer wat je moet doen, neem dan contact op met je beheerder voordat je verdergaat. Wil je echt verder gaan?",
     "I know what I'm doing" : "Ik weet wat ik doe",
     "Resetting password" : "Resetten wachtwoord",
+    "Schedule work & meetings, synced with all your devices." : "Plan je werk & afspraken, gesynced met al je toestellen.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Bewaar je collega's en vrienden op één plaats zonder hun persoonlijke gegevens te laten uitlekken.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simpele e-mailapp, handig geïntegreerd met Bestanden, Contactpersonen en Agenda.",
+    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatten, videobellen, schermdelen, online vergaderingen en webconferenties - in de browser en met mobiele apps.",
+    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Samenwerken aan tekst, spreadsheets en presentaties, gebouwt op basis van Collabora Online.",
+    "Distraction free note taking app." : "Notitie app zonder afleiding.",
     "Recommended apps" : "Aanbevolen apps",
     "Loading apps …" : "Laden apps ...",
     "Could not fetch list of apps from the App Store." : "Kon lijst met apps niet ophalen vanuit de App Store.",
@@ -169,14 +180,10 @@ OC.L10N.register(
     "Skip" : "Overslaan",
     "Installing apps …" : "Installeren apps …",
     "Install recommended apps" : "Installeer aanbevolen apps",
-    "Schedule work & meetings, synced with all your devices." : "Plan je werk & afspraken, gesynced met al je toestellen.",
-    "Keep your colleagues and friends in one place without leaking their private info." : "Bewaar je collega's en vrienden op één plaats zonder hun persoonlijke gegevens te laten uitlekken.",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simpele e-mailapp, handig geïntegreerd met Bestanden, Contactpersonen en Agenda.",
-    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatten, videobellen, schermdelen, online vergaderingen en webconferenties - in de browser en met mobiele apps.",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Samenwerken aan tekst, spreadsheets en presentaties, gebouwt op basis van Collabora Online.",
-    "Distraction free note taking app." : "Notitie app zonder afleiding.",
-    "Settings menu" : "Instellingenmenu",
     "Avatar of {displayName}" : "Avatar van {displayName}",
+    "Settings menu" : "Instellingenmenu",
+    "Loading your contacts …" : "Je contacten wordt geladen ...",
+    "Looking for {term} …" : "Kijken voor {term} …",
     "Search contacts" : "Zoek contacten",
     "Reset search" : "Zoekopdracht wissen",
     "Search contacts …" : "Zoek contacten ...",
@@ -184,26 +191,44 @@ OC.L10N.register(
     "No contacts found" : "Geen contacten gevonden",
     "Show all contacts" : "Toon alle contactpersonen",
     "Install the Contacts app" : "Installeer de Contacts app",
-    "Loading your contacts …" : "Je contacten wordt geladen ...",
-    "Looking for {term} …" : "Kijken voor {term} …",
-    "Search starts once you start typing and results may be reached with the arrow keys" : "Het zoeken begint wanneer je begint met typen en resultaten kunnen geselecteerd worden met de pijltjestoetsen",
-    "Search for {name} only" : "Zoek alleen naar {name}",
-    "Loading more results …" : "Meer resultaten laden ...",
     "Search" : "Zoeken",
     "No results for {query}" : "Geen resultaten voor {query}",
     "Press Enter to start searching" : "Druk op Enter om te beginnen zoeken",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Voer {minSearchLength} tekens of meer in om te zoeken","Voer alstublieft {minSearchLength} tekens of meer in om te zoeken"],
     "An error occurred while searching for {type}" : "Er trad een fout op bij het zoeken naar {type}",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "Het zoeken begint wanneer je begint met typen en resultaten kunnen geselecteerd worden met de pijltjestoetsen",
+    "Search for {name} only" : "Zoek alleen naar {name}",
+    "Loading more results …" : "Meer resultaten laden ...",
     "Forgot password?" : "Wachtwoord vergeten?",
     "Back to login form" : "Terug naar aanmelden",
     "Back" : "Terug",
     "Login form is disabled." : "Inlogscherm uitgeschakeld",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Het aanmeldingsformulier van Nextcloud is uitgeschakeld. Gebruik een andere inlogmogelijkheid indien beschikbaar of neem contact op met uw beheerder.",
     "More actions" : "Meer acties",
+    "Security warning" : "Beveiligingswaarschuwing",
+    "Storage & database" : "Opslag & database",
+    "Data folder" : "Gegevensmap",
+    "Install and activate additional PHP modules to choose other database types." : "Installeer en activeer aanvullende PHP modules om andere soorten databases te kiezen.",
+    "For more details check out the documentation." : "Voor meer informatie word je verwezen naar de documentatie.",
+    "Performance warning" : "Prestatiewaarschuwing",
+    "You chose SQLite as database." : "Je koos SQLite als database.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite zou alleen moeten worden gebruikt voor minimale en ontwikkelomgevingen. Voor productie raden we aan om een andere database backend te gebruiken.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Als je clients gebruikt voor bestandssynchronisatie wordt het gebruik van SQLite sterk ontraden.",
+    "Database user" : "Gebruiker database",
+    "Database password" : "Wachtwoord database",
+    "Database name" : "Naam database",
+    "Database tablespace" : "Database tablespace",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Geef het poortnummer en servernaam op (bijv. localhost:5432).",
+    "Database host" : "Databaseserver",
+    "Installing …" : "Installeren …",
+    "Install" : "Installeren",
+    "Need help?" : "Hulp nodig?",
+    "See the documentation" : "Zie de documentatie",
+    "{name} version {version} and above" : "{name} versie {version} en hoger",
     "This browser is not supported" : "Deze browser wordt niet ondersteunt",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Deze browser wordt niet ondersteunt. Upgrade a.u.b naar een nieuwere versie of een browser die wel ondersteunt wordt.",
     "Continue with this unsupported browser" : "Ga verder met deze niet-ondersteunde browser",
     "Supported versions" : "Ondersteunde versies",
-    "{name} version {version} and above" : "{name} versie {version} en hoger",
     "Search {types} …" : "Zoeken naar {types}…",
     "Choose {file}" : "Kies {file}",
     "Choose" : "Kies",
@@ -239,11 +264,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Type om bestaande projecten te vinden",
     "New in" : "Nieuw in",
     "View changelog" : "Bekijk wijzigingsoverzicht",
-    "Very weak password" : "Zeer zwak wachtwoord",
-    "Weak password" : "Zwak wachtwoord",
-    "So-so password" : "Matig wachtwoord",
-    "Good password" : "Goed wachtwoord",
-    "Strong password" : "Sterk wachtwoord",
     "No action available" : "Geen actie beschikbaar",
     "Error fetching contact actions" : "Fout bij ophalen contact acties",
     "Close \"{dialogTitle}\" dialog" : "Sluit \"{dialogTitle}\" dialoog",
@@ -281,31 +301,6 @@ OC.L10N.register(
     "File: %s" : "Bestand: %s",
     "Line: %s" : "Regel: %s",
     "Trace" : "Trace",
-    "Security warning" : "Beveiligingswaarschuwing",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Je gegevensdirectory en bestanden zijn vermoedelijk bereikbaar vanaf het internet, omdat het .htaccess-bestand niet functioneert.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Bekijk de <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentatie</a> voor Informatie over het correct configureren van je server.",
-    "Show password" : "Toon wachtwoord",
-    "Toggle password visibility" : "Omschakelen zichtbaarheid wachtwoord",
-    "Storage & database" : "Opslag & database",
-    "Data folder" : "Gegevensmap",
-    "Configure the database" : "Configureer de database",
-    "Only %s is available." : "Alleen %s is beschikbaar.",
-    "Install and activate additional PHP modules to choose other database types." : "Installeer en activeer aanvullende PHP modules om andere soorten databases te kiezen.",
-    "For more details check out the documentation." : "Voor meer informatie word je verwezen naar de documentatie.",
-    "Database account" : "Database account",
-    "Database password" : "Wachtwoord database",
-    "Database name" : "Naam database",
-    "Database tablespace" : "Database tablespace",
-    "Database host" : "Databaseserver",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Geef het poortnummer en servernaam op (bijv. localhost:5432).",
-    "Performance warning" : "Prestatiewaarschuwing",
-    "You chose SQLite as database." : "Je koos SQLite als database.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite zou alleen moeten worden gebruikt voor minimale en ontwikkelomgevingen. Voor productie raden we aan om een andere database backend te gebruiken.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Als je clients gebruikt voor bestandssynchronisatie wordt het gebruik van SQLite sterk ontraden.",
-    "Install" : "Installeren",
-    "Installing …" : "Installeren …",
-    "Need help?" : "Hulp nodig?",
-    "See the documentation" : "Zie de documentatie",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Het lijkt erop of je Nextcloud wilt herinstalleren. Maar het bestand CAN_INSTALL ontbreekt in de configdirectory. Maak het bestand CAN_INSTALL aan in je config map om verder te gaan.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Kon CAN_INSTALL niet verwijderen uit de config map. Verwijder het bestand handmatig.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Deze applicatie heeft JavaScript nodig. {linkstart}Activeer JavaScript{linkend} en ververs deze pagina.",
@@ -364,46 +359,32 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Deze %s staat momenteel in de onderhoudsstand, dat kan enige tijd duren.",
     "This page will refresh itself when the instance is available again." : "Deze pagina wordt ververst als de server weer beschikbaar is.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Neem contact op met je systeembeheerder als deze melding aanhoudt of onverwacht verscheen.",
-    "The user limit of this instance is reached." : "De limiet van het aantal gebruikers op deze server is bereikt.",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Voer de ondersteuningssleutel in de supportapp in, om de gebruikerslimiet te verhogen. Dit geeft ook toegang tot de extra voordelen die Nextcloud Enterprise te bieden heeft en is sterk aangeraden voor gebruik in bedrijven.",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Je webserver is nog niet goed ingesteld voor bestandssynchronisatie, omdat de WebDAV interface niet goed lijkt te werken.",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Je webserver is niet goed ingesteld om \"{url}\" te vinden. Meer informatie is te vinden in onze {linkstart}documentatie↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Je webserver is niet juist ingesteld voor het verwerken van \"{url}\". De oorzaak ligt waarschijnlijk bij de webserver configuratie die niet bijgewerkt is om deze map rechtstreeks beschikbaar te stellen. Vergelijk je configuratie tegen de installatieversie van de rewrite regels die je vindt in de \".htaccess\" bestanden voor Apache of met de voorbeelden in de documentatie voor Nginx die je vindt op de {linkstart}documentatie pagina↗{linkend}. Op Nginx beginnen deze regels meestal met \"location ~\" die je moet aanpassen.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Je webserver is niet goed ingesteld om .woff2 bestanden af te leveren. Dit is meestal een probleem met de Nginx configuratie. Voor Nextcloud 15 moet die worden aangepast om ook .woff2 bestanden aan te kunnen. vergelijk jouw Nginx configuratie met de aanbevolen instellingen in onze {linkstart}documentatie ↗{linkend}.",
-    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Je verbindt met je server over een beveiligd kanaal, maar je server genereert onveilige URLs. Waarschijnlijk zit je achter een reverse proxy en zijn de overschijf config variabelen niet goed ingesteld. Lees {linkstart}de documentatie hierover ↗{linkend}.",
-    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Je datamap en je bestanden zijn waarschijnlijk vanaf het internet bereikbaar.  Het .htaccess-bestand werkt niet. We raden ten zeerste aan aan om je webserver zodanig te configureren, dat de datadirectory niet bereikbaar is vanaf het internet of om je datadirectory te verplaatsen naar een locatie buiten de document-root van de webserver.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "De \"{header}\" HTTP header is niet ingesteld als \"{expected}\". Dit is een potentieel security of privacy risico en we adviseren om deze instelling te wijzigen.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "De \"{header}\" HTTP header is ingesteld als \"{expected}\". Sommige functies werken mogelijk niet zoals bedoeld en we adviseren om deze instelling te wijzigen.",
-    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "De HTTP-header \"{header}\" bevat niet de waarde \"{expected}\". Dit is een mogelijk veiligheids- of privacyrisico, aangezien het aangeraden is om deze instelling aan te passen.",
-    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "De \"{header}\" HTTP header is niet ingesteld op \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" of \"{val5}\". Hierdoor kan verwijzingsinformatie uitlekken. Zie de {linkstart}W3C aanbeveling ↗{linkend}.",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "De \"Strict-Transport-Security\" HTTP header is niet ingesteld als minimaal \"{seconds}\" seconden. Voor verbeterde beveiliging adviseren we HSTS in te schakelen zoals beschreven in de {linkstart}security tips ↗{linkend}.",
-    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Connectie via HTTP. U wordt aangeraden uw server in te stellen om het gebruik van HTTPS af te dwingen zoals beschreven in de {linkstart}beveiliging tips↗{linkend}. Zonder HTTPS zullen functies zoals \"kopieer naar klembord\" en \"service workers\" niet werken.",
     "Currently open" : "Momenteel actief",
-    "Wrong username or password." : "Verkeerde gebruikersnaam of wachtwoord.",
-    "User disabled" : "Gebruiker gedeactiveerd",
     "Login with username or email" : "Aanmelden met gebruikersnaam of e-mail",
     "Login with username" : "Aanmelden met gebruikersnaam",
-    "Username or email" : "Gebruikersnaam of email",
-    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Als dit account bestaat werd er een bericht voor wachtwoordherstel naar het overeenkomstige email adres gestuurd. Krijg je geen mail, controleer dan je email adres en/of account naam, check je spam folder of vraag hulp aan je lokale beheerder.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatten, videobellen, schermdelen, online vergaderingen en webconferenties - in de browser en met mobiele apps.",
-    "Edit Profile" : "Wijzig Profiel",
-    "The headline and about sections will show up here" : "De koplijn- en oversectie zal hier verschijnen",
     "You have not added any info yet" : "Je hebt nog geen info toegevoegd",
     "{user} has not added any info yet" : "{user} heeft nog geen info toegevoegd",
     "Error opening the user status modal, try hard refreshing the page" : "Fout bij het openen van het gebruiker status model, probeer een harde refresh van de pagina",
-    "Apps and Settings" : "Apps en Instellingen",
+    "Edit Profile" : "Wijzig Profiel",
+    "The headline and about sections will show up here" : "De koplijn- en oversectie zal hier verschijnen",
     "Error loading message template: {error}" : "Fout bij laden berichtensjabloon: {error}",
-    "Users" : "Gebruikers",
+    "Very weak password" : "Zeer zwak wachtwoord",
+    "Weak password" : "Zwak wachtwoord",
+    "So-so password" : "Matig wachtwoord",
+    "Good password" : "Goed wachtwoord",
+    "Strong password" : "Sterk wachtwoord",
     "Profile not found" : "Profiel niet gevonden",
     "The profile does not exist." : "Het profiel bestaat niet.",
-    "Create an <strong>admin account</strong>" : "Maak een <strong>beheerdersaccount</strong> aan",
-    "Username" : "Gebruikersnaam",
-    "Database user" : "Gebruiker database",
-    "This action requires you to confirm your password" : "Deze actie vereist dat je je wachtwoord bevestigt",
-    "Confirm your password" : "Bevestig je wachtwoord",
-    "Confirm" : "Bevestig",
-    "App token" : "App token",
-    "Alternative log in using app token" : "Alternatief aanmelden met app token",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Gebruik alsjeblieft de commandoregel updater omdat je een installatie hebt met meer dan 50 gebruikers."
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Je gegevensdirectory en bestanden zijn vermoedelijk bereikbaar vanaf het internet, omdat het .htaccess-bestand niet functioneert.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Bekijk de <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentatie</a> voor Informatie over het correct configureren van je server.",
+    "<strong>Create an admin account</strong>" : "<strong>Maak een admin account aan</strong>",
+    "New admin account name" : "Nieuwe admin account naam",
+    "New admin password" : "Nieuw admin wachtwoord",
+    "Show password" : "Toon wachtwoord",
+    "Toggle password visibility" : "Omschakelen zichtbaarheid wachtwoord",
+    "Configure the database" : "Configureer de database",
+    "Only %s is available." : "Alleen %s is beschikbaar.",
+    "Database account" : "Database account"
 },
 "nplurals=2; plural=(n != 1);");
