@@ -126,7 +126,6 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Nun se pudo configurar la conexón d'Oracle",
     "Oracle Login and/or password not valid" : "La cuenta y/o contraseña d'Oracle nun ye válida",
     "PostgreSQL Login and/or password not valid" : "La cuenta y/o contraseña de PostgreSQL nun ye válida",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nun ye compatible y %s nun va funcionar afayadizamente nesta plataforma. ¡Úsalu baxo'l to riegu!",
     "For the best results, please consider using a GNU/Linux server instead." : "Pa consiguir los meyores resultaos, usa un sirvidor de GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Paez qu'esta instancia de Nextcloud «%s» execútase sobre un entornu PHP de 32 bits y la opción open_basedir ta configurada en php.ini. Esto va orixinar problemes con ficheros superiores a 4GB y ye mui desaconseyable.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Quita la opción «open_basedir» de php.ini o cambia a PHP de 64 bits.",
@@ -214,37 +213,17 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Resume'l testu amenorgando la so llongura ensin perder la información importante.",
     "Extracts topics from a text and outputs them separated by commas." : "Estrái temes d'un testu y devuélvelos separtaos per comes.",
     "Education Edition" : "Edición educativa",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "L'usuariu que tien la sesión aniciada ha ser d'alministración, un sodominiu o tener un permisu especial p'acceder a esta opción",
-    "Logged in user must be an admin or sub admin" : "L'usuariu que tien la sesión aniciada ha ser d'alministración o un sodominiu",
-    "Logged in user must be an admin" : "L'usuariu que tien la sesión aniciada ha ser d'alministración",
     "File name is a reserved word" : "El nome de ficheru ye una pallabra acutada",
     "File name contains at least one invalid character" : "El nome del ficheru contién polo menos un caráuter inváldu",
     "File name is too long" : "El nome del ficheru ye mui llongu",
-    "Help" : "Ayuda",
     "Users" : "Usuarios",
-    "Unknown user" : "Usuariu desconocíu",
-    "Enter the database username and name for %s" : "Introduz el nome d'usuariu y el nome de la base de datos pa: %s",
-    "Enter the database username for %s" : "Introduz el nome d'usuariu de la base de datos pa: %s",
-    "MySQL username and/or password not valid" : "El nome d'usuariu y/o la contraseña de MySQL son inválidos",
-    "Oracle username and/or password not valid" : "El nome d'usuariu y/o la contraseña d'Oracle son inválidos",
-    "PostgreSQL username and/or password not valid" : "El nome d'usuariu y/o la contraseña de PostgreSQL son inválidos",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartío «%2$s» contigo y quier amestar:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s compartío «%2$s» contigo y quier amestar",
     "»%s« added a note to a file shared with you" : "«%s» amestó una nota a un ficheru compartío contigo",
     "Open »%s«" : "Abrir «%s»",
-    "Sharing %s failed, because this item is already shared with user %s" : "La compartición de «%s» falló porque esti elementu yá ta compartíu col usuariu «%s»",
     "%1$s shared »%2$s« with you" : "%1$s compartió «%2$s» contigo",
     "%1$s shared »%2$s« with you." : "%1$s compartió «%2$s» contigo.",
     "Click the button below to open it." : "Calca nel botón p'abrilo.",
-    "The username is already being used" : "El nome d'usuariu yá ta n'usu",
-    "Could not create user" : "Nun se pudo crear l'usuariu",
-    "A valid username must be provided" : "Ha fornise un nome d'usuariu válidu",
-    "Username contains whitespace at the beginning or at the end" : "El nome d'usuariu contién un espaciu nel comienzu o al final",
-    "Username must not consist of dots only" : "El nome d'usuariu nun ha tar formáu namás por puntos",
-    "Username is invalid because files already exist for this user" : "El nome d'usuariu ye inválidu porque yá esisten los ficheros pa esti ficheru",
-    "User disabled" : "L'usuariu ta desactiváu",
-    "Your data directory is readable by other users." : "Los demás usuarios puen lleer el to direutoriu de datos.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Camuda los permisos a 0770 y, polo tanto, los demás usuarios nun puen llistar el direutoriu.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegúrate de que'l ficheru llamáu «.ocdata» ta nel raigañu del direutoriu de datos."
 },
 "nplurals=2; plural=(n != 1);");
